
#ifndef __RENDERERINTERFACE_H_
#define __RENDERERINTERFACE_H_
/**************************************************************************************
* This file is part of the GameFramework project released by Wazoo Enterprises Inc.
* under the GNU Public License. 
*
* Any projects using this code must attach these copyright notices along with their
* own as outlined at http://www.gnu.org
*
* Copyright 2003 by Wazoo Enterprises Inc.
* To contact the auther, send a message to wazoo@wazooenterprises.com
*
****************************************************************************************/

//////////////////////////////////
// class: rendererInterface
// description: This class is our "base class" for obtaining
//              some sort of GraphicsAPI independance. 
//              We'll use this interface object to declare
//              "high-level" methods which our "low-level" DLL
//              projects will implement.
//////////////////////////////////
#include <windows.h>

/**
* version 1.1
* Added our Vertex Buffer interface
**/
#include "vbInterface.h"

class rendererInterface
{
protected:
	HWND m_hWnd;
	DWORD m_dwWidth;
	DWORD m_dwHeight;
	DWORD m_dwDepth;
	BOOL m_bWindowed;

public:
	/**
	* version 1.1
	* Added a pointer to our Vertex Buffer interface object
	**/
	vbInterface* m_pVB;

public:
	rendererInterface(){};
	virtual ~rendererInterface(){};

	//method to create and initialize our hardware
    virtual HRESULT createDevice(HWND, DWORD, DWORD, DWORD, BOOL) = 0;

    //method to destroy it
    virtual void destroyDevice() = 0;

    //method to begin rendering primitives
    virtual HRESULT beginRenderingScene() = 0;

    //method to end rendering primitives
    virtual void endRenderingScene() = 0;

    //method to change the screen clearing color
    virtual void setClearColor(FLOAT, FLOAT, FLOAT, FLOAT) = 0;

};

extern "C"
{
	HRESULT createRendererInterface(rendererInterface **pInterface);
	typedef HRESULT (*CREATERENDERERINTERFACE)(rendererInterface **pInterface);

	HRESULT destroyRendererInterface(rendererInterface **pInterface);
	typedef HRESULT (*DESTROYRENDERERINTERFACE)(rendererInterface **pInterface);
}

#endif